<?php
/**
 * Order Status Rules for WooCommerce - Section Settings
 *
 * @version 1.6.0
 * @since   1.0.0
 *
 * @author  Algoritmika Ltd.
 */

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

if ( ! class_exists( 'Alg_WC_Order_Status_Rules_Settings_Section' ) ) :

class Alg_WC_Order_Status_Rules_Settings_Section {

	/**
	 * Constructor.
	 *
	 * @version 1.1.0
	 * @since   1.0.0
	 */
	function __construct() {
		add_filter( 'woocommerce_get_sections_alg_wc_order_status_rules',              array( $this, 'settings_section' ) );
		add_filter( 'woocommerce_get_settings_alg_wc_order_status_rules_' . $this->id, array( $this, 'get_settings' ), PHP_INT_MAX );
	}

	/**
	 * settings_section.
	 *
	 * @version 1.0.0
	 * @since   1.0.0
	 */
	function settings_section( $sections ) {
		$sections[ $this->id ] = $this->desc;
		return $sections;
	}

	/**
	 * get_product_title.
	 *
	 * @version 1.6.0
	 * @since   1.6.0
	 */
	function get_product_title( $product_id ) {
		return get_the_title( $product_id ) . " (#{$product_id})";
	}

	/**
	 * get_missing_product_title.
	 *
	 * @version 1.6.0
	 * @since   1.6.0
	 */
	function get_missing_product_title( $product_id ) {
		return sprintf( __( 'Product #%s', 'order-status-rules-for-woocommerce' ), $product_id );
	}

	/**
	 * get_missing_product_cat_title.
	 *
	 * @version 1.6.0
	 * @since   1.6.0
	 */
	function get_missing_product_cat_title( $term_id ) {
		return sprintf( __( 'Product category #%s', 'order-status-rules-for-woocommerce' ), $term_id );
	}

	/**
	 * get_missing_product_tag_title.
	 *
	 * @version 1.6.0
	 * @since   1.6.0
	 */
	function get_missing_product_tag_title( $term_id ) {
		return sprintf( __( 'Product tag #%s', 'order-status-rules-for-woocommerce' ), $term_id );
	}

}

endif;
